@@ -1,17 +1,21 @@
 # All the Newsdata supported API URL
 BASE_URL = 'https://newsdata.io/api/1/'
 
-# Latest News URL 
+# Latest News URL
 NEWS_URL = BASE_URL + 'news'
 
 
-# News Archive URL 
+# News Archive URL
 ARCHIVE_URL = BASE_URL + 'archive'
 
 
-# News Sources URL 
+# News Sources URL
 SOURCES_URL = BASE_URL + 'sources'
 
 
-# Default request timeout is 300 seconds 
-DEFAULT_REQUEST_TIMEOUT = 300
\ No newline at end of file
+# News Crypto URL
+CRYPTO_URL = BASE_URL + 'crypto'
+
+
+# Default request timeout is 300 seconds
+DEFAULT_REQUEST_TIMEOUT = 300
