@@ -21,4 +21,9 @@ class test_newsdataapi(unittest.TestCase):
     def test_sources_api(self):
         response = self.api.sources_api()
 
-        self.assertEqual(response['status'], "success")
\ No newline at end of file
+        self.assertEqual(response['status'], "success")
+
+    def test_crypto_api(self):
+        response = self.api.crypto_api()
+
+        self.assertEqual(response['status'], "success")
